@@ -40,7 +40,7 @@ class Surface;
  */
 class KMPLAYER_EXPORT ActorAgent {
 public:
-    enum ActorType { Any, Audio, AudioVideo, Image, Text };
+    enum ActorType { Any, Audio, AudioVideo, Image, Text, Data };
     //typedef QValueList <Actor *> MediaList;
 
     ActorAgent (Control *ctrl);
@@ -84,7 +84,7 @@ protected:
 
 //------------------------%<----------------------------------------------------
 
-class KMPLAYER_EXPORT MediaInfo : public AsyncJobInterface {
+class KMPLAYER_EXPORT MediaInfo : public IOJobListener {
 public:
     MediaInfo (Node *node, ActorAgent::ActorType type);
     ~MediaInfo ();
@@ -104,14 +104,15 @@ public:
     ActorAgent::ActorType type;
 
 private:
-    virtual void jobData (Job *job, ByteArray &data);
-    virtual void jobResult (Job *job);
+    virtual void jobData (IOJob *job, ByteArray &data);
+    virtual void jobResult (IOJob *job);
+    virtual void redirected (IOJob * job, const String & uri);
 
     void ready ();
     bool readChildDoc ();
 
     Node *node;
-    Job *job;
+    IOJob *job;
 };
 
 
@@ -189,7 +190,7 @@ public:
     void unpause ();
 
     bool isEmpty () const;
-    unsigned render (cairo_surface_t *similar, int width, int height);
+    unsigned render (cairo_surface_t *similar, ISize size);
     void sizes (Single &width, Single &height);
     void updateRender ();
     bool movieTimer ();
