@@ -231,7 +231,7 @@ void ATOM::MediaGroup::addSummary (Node *rating_node) {
                 String t = e->getAttribute (TrieString ("time"));
                 if (!t.isEmpty ())
                     images += String (" dur=\"") +
-                        String::number (Mrl::parseTimeString (t) / 10) +
+                        String::number (Mrl::parseTimeString (t) / 100.0) +
                         Char ('"');
                 images += String (" transIn=\"fade\" transOut=\"ellipsewipe\" fit=\"meet\"/>");
                 img_count++;
