@@ -28,12 +28,30 @@ typedef struct _Application Application;
 
 namespace KMPlayer {
 
+class UnixProcess;
+class UnixProcessListener;
+
 static const short id_node_recent_document = 30;
 static const short id_node_recent_node = 31;
 static const short id_node_disk_document = 32;
 static const short id_node_disk_node = 33;
 static const short id_node_html_object = 34;
 static const short id_node_html_embed = 35;
+static const short id_node_gen_generator = 36;
+static const short id_node_gen_input = 37;
+static const short id_node_gen_uri = 38;
+static const short id_node_gen_literal = 39;
+static const short id_node_gen_ask = 40;
+static const short id_node_gen_title = 41;
+static const short id_node_gen_description = 42;
+static const short id_node_gen_process = 43;
+static const short id_node_gen_program = 44;
+static const short id_node_gen_argument = 45;
+static const short id_node_gen_predefined = 46;
+static const short id_node_gen_document = 47;
+static const short id_node_gen_http_get = 48;
+static const short id_node_gen_http_key_value = 49;
+static const short id_node_gen_sequence = 50;
 
 class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
 public:
@@ -63,6 +81,7 @@ public:
     void *message (KMPlayer::MessageType msg, void *content=NULL);
     KMPlayer::Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
+    String path;
     Application * app;
 };
 
@@ -134,6 +153,47 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "object"; }
 };
 
+class KMPLAYER_NO_EXPORT Generator
+    : public FileDocument, public UnixProcessListener {
+public:
+    Generator (KMPlayer::Control *src)
+        : FileDocument (id_node_gen_document, String (), src),
+          unix_process (NULL), data (NULL) {}
+    void activate ();
+    void begin ();
+    void deactivate ();
+    void *message (KMPlayer::MessageType msg, void *content=NULL);
+    Node *childFromTag (const String & tag);
+    KDE_NO_EXPORT const char *nodeName () const { return "generator"; }
+
+    void readEvent (UnixProcess *);
+    void writeEvent (UnixProcess *);
+    void processExited (UnixProcess *);
+
+private:
+    String genReadProcess (Control *ctrl, Node *n);
+    String genReadInput (Control *ctrl, Node *n);
+    String genReadString (Control *ctr, Node *n);
+    String genReadUriGet (Control *ctr, Node *n);
+    String genReadAsk (Control *ctr, Node *n);
+
+    UnixProcess *unix_process;
+    TextStream *data;
+    String process;
+    unsigned write_pos;
+    bool canceled;
+    bool quote;
+};
+
+class KMPLAYER_NO_EXPORT GeneratorElement : public Element {
+public:
+    GeneratorElement (NodePtr &doc, const String &t, short id)
+        : Element (doc, id), tag (t) {}
+    Node *childFromTag (const String & tag);
+    KDE_NO_EXPORT const char *nodeName () const { return (const char *) tag; }
+    String tag;
+};
+
 }  // KMPlayer namespace
 
 #endif //_KMPLAYER_LISTS_H_
