@@ -77,7 +77,7 @@ void *SourceDocument::message (MessageType msg, void *data) {
         return VIEWAREA(m_control->m_app)->getSurface ((Mrl *) data);
 
     case MsgInfoString:
-        app_set_info_content (m_control->m_app, 
+        app_set_info_content (m_control->m_app,
                 data ? (const char *) *((String *) data) : "", false);
         return NULL;
 
@@ -373,7 +373,7 @@ void Control::openDocument (NodePtr doc, NodePtr cur) {
     app_set_title ((const char *) cur_url, m_app);
     back_request = cur;
     g_timeout_add (0, playSchedule, static_cast <void *> (this));
-    updatePlaylistView (true);
+    updatePlaylistView ();
 }
 
 ViewArea *Control::viewArea () const {
@@ -656,7 +656,8 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
             m_process->pause ();
         VIEWAREA(m_app)->setEventFiltering (m_app, true);
         app_set_playing (m_app, ns > Node::state_deferred ? PLAYING : PAUSED);
-    } else if (ns == Node::state_activated) {
+    } else if (ns == Node::state_activated ||
+            (os == Node::state_init && ns == Node::state_deferred)) {
         if (n == playlist_data->document) {
             VIEWAREA(m_app)->setEventFiltering (m_app, true);
             app_set_playing (m_app, PLAYING);
@@ -1002,9 +1003,9 @@ void app_set_info_content (Application *app, const char *utf8, bool plaintext) {
         gtk_html_load_from_string (GTK_HTML (app->html_infopanel_view),utf8,-1);
     } else {
         gtk_widget_hide (app->html_viewport);
-        gtk_widget_show (app->info_viewport);
         gtk_text_buffer_set_text (gtk_text_view_get_buffer
                 (GTK_TEXT_VIEW (app->infopanel_view)), utf8, -1);
+        gtk_widget_show (app->info_viewport);
     }
 }
 
