@@ -38,6 +38,9 @@ namespace KMPlayer {
 class ActorAgent;
 class ViewArea;
 
+String getUserInput (Application *app,
+        const gchar *title, const gchar *desc, const gchar *def);
+
 struct MAEMO_NO_EXPORT PlayListData {
     PlayListData (short id, PlayListData * n = 0L);
     NodePtr document;
@@ -54,7 +57,7 @@ struct MAEMO_NO_EXPORT PlayListData {
 
 class MAEMO_NO_EXPORT Control : public PlayListNotify, public ProcessNotify {
     Process * m_process;
-    Rect video_rect;
+    IRect video_rect;
     int m_doc_timer;
     GtkWidget *progress_banner;
 public:
@@ -70,7 +73,7 @@ public:
     void updatePlaylistView (bool force=false);
     ViewArea *viewArea () const;
     unsigned long videoOutput () const;
-    void addRecent (const String &url);
+    void addRecent (const String &url, const String &title);
     void setCurrentSelected (NodePtr node);
     /**
      * PlayListNotify implementation
@@ -119,7 +122,10 @@ public:
     PlayListData *playlist_data;
     NodePtrW back_request;
     NodePtrW current_selected;
+    NodePtrW current_generator;
+    NodeStoreList generators;
     String cur_url;
+    String data_dir;
     Config * m_config;
     Application * m_app;
     int paint_timer;
@@ -127,7 +133,7 @@ public:
     int blanking_timer;
     int width, height;
     float aspect;
-    Rect paint_rect;
+    IRect paint_rect;
     bool in_progress_update;
     bool request_download;
     bool use_xvideo;
