@@ -90,14 +90,12 @@ KDE_NO_CDTOR_EXPORT
 Connection::Connection (NodeRefList *ls, Node *node, Node *inv)
  : connectee (inv), listeners (ls) {
     if (listeners) {
-        NodeRefItemPtr nci = new NodeRefItem (node);
+        NodeRefItem *nci = new NodeRefItem (node);
         ls->append (nci);
         listen_item = nci;
     }
 }
 
-//-----------------------------------------------------------------------------
-
 KDE_NO_EXPORT void Connection::disconnect () {
     if (listen_item && listeners)
         listeners->remove (listen_item);
@@ -436,6 +434,10 @@ String Node::nodeValue () const {
     return String ();
 }
 
+template <> void List<NodeRefItem>::remove (NodeRefItem *c) {
+        removeImpl (c);
+}
+
 //-----------------------------------------------------------------------------
 
 namespace {
@@ -598,6 +600,7 @@ String Title::caption () const {
 }
 
 void Title::setCaption (const String &t) {
+    setAttribute (StringPool::attr_title, t);
     title = t;
 }
 
