@@ -800,8 +800,10 @@ String KMPlayer::getUserInput (Application *app,
         gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), lbl);
     }
     GtkWidget *edit = gtk_entry_new();
-    if (def)
+    if (def) {
         gtk_entry_set_text (GTK_ENTRY (edit), def);
+        gtk_editable_select_region (GTK_EDITABLE (edit), 0, -1);
+    }
     gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), edit);
     gtk_window_set_default_size(GTK_WINDOW(dialog), 400, 150);
 
@@ -871,8 +873,6 @@ void cb_playlistTitle (GtkButton *button, Application *app) {
             String title = node->caption ();
             title = getUserInput (app, "New Title", "Enter new title", title);
             if (!title.isNull ()) {
-                static_cast <Element *> (node)->setAttribute
-                    (StringPool::attr_title, title);
                 node->setCaption (title);
                 node->document ()->m_tree_version++;
                 updateTree (app, app->playlists_tree_id);
