@@ -37,6 +37,15 @@
 
 using namespace KMPlayer;
 
+KMPLAYER_NO_CDTOR_EXPORT ByteArrayImpl::ByteArrayImpl (const ByteArrayImpl & b)
+ : m_data (b.m_size ? (char *) malloc (b.m_size) : 0L),
+   m_size (b.m_size),
+   m_capacity (b.m_size),
+   data_owner (true) {
+    if (m_size)
+        memcpy (m_data, b.m_data, m_size);
+}
+
 KMPLAYER_NO_EXPORT void ByteArrayImpl::resize (unsigned ns) {
     if (ns > m_capacity) {
         char * tmp = (char *) malloc (ns);
@@ -51,15 +60,28 @@ KMPLAYER_NO_EXPORT void ByteArrayImpl::resize (unsigned ns) {
         m_size = ns;
 }
 
-//-----------------------------------------------------------------------------
-
-void Shared::clear () {
-    if (data)
-        data->unref ();
-    data = 0L;
+KMPLAYER_NO_EXPORT
+ByteArrayImpl & ByteArrayImpl::operator = (const ByteArrayImpl & b) {
+    if (m_data && data_owner)
+        free (m_data);
+    m_data = (b.m_size ? (char*) malloc (b.m_size) : 0L);
+    m_size = b.m_size;
+    m_capacity = b.m_size;
+    if (m_size)
+        memcpy (m_data, b.m_data, m_size);
 }
 
-void Shared::attach (const Shared & other) {
+KMPLAYER_NO_EXPORT ByteArrayImpl &ByteArrayImpl::operator = (const char *b) {
+    int len = strlen (b);
+    resize (len);
+    memcpy (m_data, b, len);
+    return *this;
+}
+
+//-----------------------------------------------------------------------------
+
+template <>
+void Shared<SharedChars>::attach (const Shared<SharedChars> &other) {
     if (data != other.data) {
         if (other.data)
             other.data->ref ();
@@ -69,31 +91,28 @@ void Shared::attach (const Shared & other) {
     }
 }
 
-void Shared::attach (char * p) {
-    if (!data || data->ptr != p) {
-        SharedChars * tmp = p ? new SharedChars (p) : 0L;
-        if (data)
-            data->unref ();
-        data = tmp;
-    }
-}
-
-void Shared::detach () {
-    if (data && data->ref_count > 1) {
-        SharedChars * tmp = new SharedChars (g_strdup (data->ptr));
-        if (data)
-            data->unref ();
-        data = tmp;
-    }
-}
-
-//-----------------------------------------------------------------------------
-
 GLibString::GLibString (const Char & ch) {
     gchar buf [8];
     int nr = g_unichar_to_utf8 (ch.unicode (), buf);
     buf [nr] = 0;
-    attach (g_strdup (buf));
+    takeUtf8 (g_strdup (buf));
+}
+
+void GLibString::takeUtf8 (char * p) {
+    if (!data || data->ptr != p) {
+        SharedChars *tmp = p ? new SharedChars (p) : 0L;
+        if (data)
+            data->unref ();
+        data = tmp;
+    }
+}
+
+int GLibString::compare (const char *str) const {
+    if (!str && !data)
+        return 0;
+    if (str && data)
+        return strcmp (str, data->ptr);
+    return data ? 1 : -1;
 }
 
 int GLibString::compare (const GLibString & str) const {
@@ -107,10 +126,10 @@ int GLibString::compare (const GLibString & str) const {
 void GLibString::take (char * s) {
     const gchar *end;
     if (g_utf8_validate (s, -1, &end)) {
-        attach (s);
+        takeUtf8 (s);
     } else {
         gsize bytes_read, bytes_written;
-        attach (g_locale_to_utf8 (s, -1, &bytes_read, &bytes_written, 0L));
+        takeUtf8 (g_locale_to_utf8 (s, -1, &bytes_read, &bytes_written, 0L));
     }
 }
 
@@ -126,16 +145,24 @@ GLibString & GLibString::operator = (const Char & ch) {
     gchar buf [8];
     int nr = g_unichar_to_utf8 (ch.unicode (), buf);
     buf [nr] = 0;
-    attach (g_strdup (buf));
+    takeUtf8 (g_strdup (buf));
     return *this;
 }
 
 GLibString & GLibString::operator += (const GLibString & str) {
     if (!data) {
         if (str.data)
-            attach (g_strdup (str.data->ptr));
+            takeUtf8 (g_strdup (str.data->ptr));
     } else if (str.data)
-        attach (g_strconcat (data->ptr, str.data->ptr, 0L));
+        takeUtf8 (g_strconcat (data->ptr, str.data->ptr, 0L));
+    return *this;
+}
+
+KMPLAYER_NO_EXPORT GLibString & GLibString::operator += (const char *str) {
+    if (!data)
+        takeUtf8 (g_strdup (str));
+    else
+        takeUtf8 (g_strconcat (data->ptr, str, 0L));
     return *this;
 }
 
@@ -280,9 +307,9 @@ GLibString GLibString::mid (const int index, unsigned len) const {
         eos = g_utf8_next_char (eos);
     GLibString str;
     if (!eos || !*eos)
-        str.attach (g_strdup (off));
+        str.takeUtf8 (g_strdup (off));
     else
-        str.attach (g_strndup (off, eos-off));
+        str.takeUtf8 (g_strndup (off, eos-off));
     return str;
 }
 
@@ -295,7 +322,7 @@ GLibString GLibString::left (int index) const {
     if (!off)
         return GLibString ();
     GLibString str;
-    str.attach (g_strndup (data->ptr, off - data->ptr));
+    str.takeUtf8 (g_strndup (data->ptr, off - data->ptr));
     return str;
 }
 
@@ -306,7 +333,7 @@ void GLibString::truncate (int pos) {
         } else {
             gchar * epos = g_utf8_offset_to_pointer (data->ptr, pos);
             if (epos)
-                attach (g_strndup (data->ptr, epos - data->ptr));
+                takeUtf8 (g_strndup (data->ptr, epos - data->ptr));
         }
     }
 }
@@ -477,6 +504,15 @@ KMPLAYER_NO_EXPORT String GnomeVFSUrl::decode_string (const String & s) {
     return str;
 }
 
+KMPLAYER_NO_EXPORT String GnomeVFSUrl::encode_string (const String & s) {
+    if (s.isEmpty ())
+        return String ();
+    String str;
+    GLibString &gs = str;
+    gs.take(gnome_vfs_escape_string ((const char *) s));
+    return str;
+}
+
 KMPLAYER_NO_EXPORT bool GnomeVFSUrl::isLocalFile () const {
     if (m_vfsurl)
         return gnome_vfs_uri_is_local (m_vfsurl) ||
@@ -549,16 +585,16 @@ String GLibTextStream::readLine () {
 #if 0
 namespace KMPlayer {
 
-    class GnomeVFSGetJob : public JobInterface {
+    class GnomeVFSGetJob : public IOJob {
     public:
-        GnomeVFSGetJob (AsyncJobInterface * rec, const String & u);
+        GnomeVFSGetJob (IOJobListener * rec, const String & u);
         ~GnomeVFSGetJob ();
         void kill (bool quiet = true);
         void finished ();
         bool error ();
 
         GnomeVFSAsyncHandle * network_handle;
-        AsyncJobInterface * m_receiver;
+        IOJobListener * m_receiver;
         bool job_closed;
         bool job_error;
         bool keep_quiet;
@@ -566,7 +602,7 @@ namespace KMPlayer {
         char read_buf [2048];
     };
 
-    Job * asyncGet (AsyncJobInterface * receiver, const String & url) {
+    IOJob * asyncGet (IOJobListener * receiver, const String & url) {
         return new GnomeVFSGetJob (receiver, url);
     }
 }
@@ -636,7 +672,7 @@ static void cb_async_get_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult resul
         gnome_vfs_async_read (handle, get->read_buf, sizeof (get->read_buf) -1, cb_async_get_read, p);
 }
 
-GnomeVFSGetJob::GnomeVFSGetJob (AsyncJobInterface * rec, const String &url)
+GnomeVFSGetJob::GnomeVFSGetJob (IOJobListener * rec, const String &url)
  : m_receiver (rec), network_handle (0L),
    job_closed (false), job_error (false),
    keep_quiet (false), continuing (false) {
@@ -692,22 +728,19 @@ static gint easyCompare (gconstpointer a, gconstpointer b) {
     return (long)a - (long)b;
 }
 
-namespace {
-
-    struct FdWatch {
-        int fd;
-        int chan_read_watch;
-    };
-    class KMPLAYER_NO_EXPORT CurlGetJob : public JobInterface {
+namespace KMPlayer {
+    class CurlGetJob {
     public:
-        CurlGetJob (AsyncJobInterface * rec, const String & u);
+        CurlGetJob (IOJobListener * rec, const String & u);
         ~CurlGetJob ();
-        void kill (bool quiet = true);
-        bool error ();
-        unsigned long contentLength() const { return content_length; }
-        String contentType () const { return content_type; }
 
-        AsyncJobInterface * m_receiver;
+        void init (IOJob *job);
+
+        static size_t headerLine( void *p, size_t sz, size_t n, void *strm);
+        static size_t dataReceived (void *p, size_t sz, size_t n, void *strm);
+        static gboolean findKilledJob (gpointer key, gpointer val, gpointer d);
+
+        IOJobListener * m_receiver;
 
         static bool global_init;
         static CURLM *multi;
@@ -723,16 +756,29 @@ namespace {
     };
 }
 
+namespace {
+
+    struct FdWatch {
+        int fd;
+        int chan_read_watch;
+    };
+
+}
+
 namespace KMPlayer {
-    Job * asyncGet (AsyncJobInterface * receiver, const String & url) {
-        return new CurlGetJob (receiver, url);
+
+    IOJob *asyncGet (IOJobListener *receiver, const String &url) {
+        return new IOJob (new CurlGetJob (receiver, url));
     }
 }
 
-static gboolean findKilledJob (gpointer key, gpointer value, gpointer data) {
-    CurlGetJob *job = (CurlGetJob *)value;
-    if (job->killed) {
-        *(CurlGetJob **)data = job;
+inline gboolean
+CurlGetJob::findKilledJob (gpointer key, gpointer value, gpointer data) {
+    IOJob *job = (IOJob *)value;
+    CurlGetJob *self = job->d;
+
+    if (self->killed) {
+        *(IOJob **)data = job;
         return true;
     }
     return false;
@@ -798,8 +844,8 @@ static void curlPerformMulti () {
         curlCode = curl_multi_perform (CurlGetJob::multi, &running_handles);
 	if (curl_job_killed)
             do {
-                CurlGetJob *job = NULL;
-                g_tree_traverse (easy_list, findKilledJob, G_IN_ORDER, &job);
+                IOJob *job = NULL;
+                g_tree_traverse (easy_list, CurlGetJob::findKilledJob, G_IN_ORDER, &job);
                 if (job)
                     delete job;
                 else
@@ -810,7 +856,7 @@ static void curlPerformMulti () {
     CURLMsg* msg = curl_multi_info_read (CurlGetJob::multi, &messages);
     while (msg) {
         if (CURLMSG_DONE == msg->msg) {
-            CurlGetJob *job = (CurlGetJob *)g_tree_lookup (easy_list, msg->easy_handle);
+            IOJob *job = (IOJob *)g_tree_lookup (easy_list, msg->easy_handle);
             if (job)
                 delete job;
         }
@@ -834,53 +880,56 @@ static gboolean curlChannelRead (GIOChannel *src, GIOCondition c, gpointer d) {
     curlPerformMulti ();
 }
 
-static
-size_t curlHeaderLine( void *ptr, size_t size, size_t nmemb, void *stream) {
-    CurlGetJob *job = (CurlGetJob *) stream;
+size_t CurlGetJob::headerLine( void *ptr, size_t size, size_t nmemb, void *stream) {
+    IOJob *job = (IOJob *) stream;
+    CurlGetJob *self = job->d;
     //char buf[256];
     //snprintf (buf, sizeof (buf), "%s", (char *)ptr);
     //debugLog() << "header: " << buf << endl;
     // Last-Modified:
-    if (!job->killed) {
+    if (!self->killed) {
         if (!strncmp ((char *)ptr, "HTTP/", 5)) {
             char *p = strchr ((char *)ptr + 5, ' ');
             if (p) {
                 int rc = strtol (p +1, NULL, 10);
                 if (rc >= 400)
-                    job->error_code = rc;
+                    self->error_code = rc;
                 else if (rc >= 300)
-                    job->redirected = true;
+                    self->redirected = true;
             }
-        } else if (job->redirected && !strncasecmp ((char *)ptr, "location:", 9)) {
+        } else if (self->redirected && !strncasecmp ((char *)ptr, "location:", 9)) {
             String nuri ((char *) ptr + 9, size * nmemb - 9);
-            job->m_receiver->redirected (job, nuri.stripWhiteSpace ());
-            job->redirected = false;
+            self->redirected = false;
+            self->m_receiver->redirected (job, nuri.stripWhiteSpace ());
         } else if (!strncasecmp ((char *)ptr, "content-length:", 15)) {
-            job->content_length = strtol ((char *)ptr + 15, NULL, 10);
+            self->content_length = strtol ((char *)ptr + 15, NULL, 10);
         } else if (!strncasecmp ((char *)ptr, "content-type:", 13)) {
-            job->content_type = String (
+            self->content_type = String (
                     (char *)ptr + 13, size * nmemb - 13).stripWhiteSpace ();
         }
     }
     return size * nmemb;
 }
 
-static
-size_t curlDataReceived (void *ptr, size_t size, size_t nmemb, void *stream) {
-    CurlGetJob *job = (CurlGetJob *) stream;
+size_t CurlGetJob::dataReceived (void *ptr, size_t size, size_t nmemb, void *stream) {
+    IOJob *job = (IOJob *) stream;
+    CurlGetJob *self = job->d;
     ByteArray data ((char *)ptr, size * nmemb);
-    //debugLog() << "curlDataReceived " << (size * nmemb) << endl;
-    if (!job->killed)
-        job->m_receiver->jobData (job, data);
+    //debugLog() << "dataReceived " << (size * nmemb) << endl;
+    if (!self->killed)
+        self->m_receiver->jobData (job, data);
     return size * nmemb;
 }
 static int job_count;
 
 KMPLAYER_NO_CDTOR_EXPORT
-CurlGetJob::CurlGetJob (AsyncJobInterface * rec, const String & u)
+CurlGetJob::CurlGetJob (IOJobListener * rec, const String & u)
  : m_receiver (rec), url (u),
    quiet (false), killed (false), redirected (false),
-   error_code (0), content_length (0) {
+   error_code (0), content_length (0)
+{}
+
+void CurlGetJob::init (IOJob *job) {
     if (!global_init) {
         global_init = !curl_global_init (CURL_GLOBAL_ALL);
         easy_list = g_tree_new (easyCompare);
@@ -890,13 +939,13 @@ CurlGetJob::CurlGetJob (AsyncJobInterface * rec, const String & u)
         multi = curl_multi_init ();
     easy = curl_easy_init ();
     debugLog() << "CurlGetJob::CurlGetJob " << easy << " " << ++job_count << endl;
-    g_tree_insert (easy_list, easy, this);
+    g_tree_insert (easy_list, easy, job);
     //curl_easy_setopt (easy, CURLOPT_VERBOSE, true);
     curl_easy_setopt (easy, CURLOPT_NOPROGRESS, true);
-    curl_easy_setopt (easy, CURLOPT_WRITEFUNCTION, curlDataReceived);
-    curl_easy_setopt (easy, CURLOPT_WRITEDATA, this);
-    curl_easy_setopt (easy, CURLOPT_HEADERFUNCTION, curlHeaderLine);
-    curl_easy_setopt (easy, CURLOPT_WRITEHEADER, this);
+    curl_easy_setopt (easy, CURLOPT_WRITEFUNCTION, CurlGetJob::dataReceived);
+    curl_easy_setopt (easy, CURLOPT_WRITEDATA, job);
+    curl_easy_setopt (easy, CURLOPT_HEADERFUNCTION, CurlGetJob::headerLine);
+    curl_easy_setopt (easy, CURLOPT_WRITEHEADER, job);
     curl_easy_setopt (easy, CURLOPT_FOLLOWLOCATION, 1);
     curl_easy_setopt (easy, CURLOPT_MAXREDIRS, 10);
     //CURLSH *curl_share_init( );
@@ -915,7 +964,7 @@ CurlGetJob::CurlGetJob (AsyncJobInterface * rec, const String & u)
         debugLog() << "CurlGetJob add to multi failure" << endl;
 
     if (!curl_timeout_timer)
-        curl_timeout_timer = g_timeout_add (50, curlTimeOut, this);
+        curl_timeout_timer = g_timeout_add (50, curlTimeOut, NULL);
 }
 
 KMPLAYER_NO_CDTOR_EXPORT CurlGetJob::~CurlGetJob () {
@@ -924,8 +973,6 @@ KMPLAYER_NO_CDTOR_EXPORT CurlGetJob::~CurlGetJob () {
         curl_multi_remove_handle (multi, easy);
         curl_easy_cleanup (easy);
         g_tree_remove (easy_list, easy);
-        if (!quiet)
-            m_receiver->jobResult (this);
     }
     if (0) {
         curl_multi_cleanup (multi);
@@ -933,9 +980,22 @@ KMPLAYER_NO_CDTOR_EXPORT CurlGetJob::~CurlGetJob () {
     }
 }
 
-KMPLAYER_NO_EXPORT void CurlGetJob::kill (bool q) {
-    quiet = q;
-    killed = true;
+KMPLAYER_NO_EXPORT IOJob::IOJob (IOJobPrivate *priv) : d (priv) {
+    priv->init (this);
+}
+
+KMPLAYER_NO_EXPORT IOJob::~IOJob () {
+    IOJobListener *listener = d->easy && !d->quiet ? d->m_receiver : NULL;
+
+    if (listener)
+        listener->jobResult (this);
+
+    delete d;
+}
+
+KMPLAYER_NO_EXPORT void IOJob::kill (bool q) {
+    d->quiet = q;
+    d->killed = true;
     curl_job_killed = true;
     if (!in_perform_multi) {
         delete this;
@@ -943,8 +1003,16 @@ KMPLAYER_NO_EXPORT void CurlGetJob::kill (bool q) {
     }
 }
 
-KMPLAYER_NO_EXPORT bool CurlGetJob::error () {
-    return error_code;
+KMPLAYER_NO_EXPORT bool IOJob::error () {
+    return d->error_code;
+}
+
+unsigned long IOJob::contentLength() const {
+    return d->content_length;
+}
+
+String IOJob::contentType () const {
+    return d->content_type;
 }
 
 //-----------------------------------------------------------------------------
@@ -1016,7 +1084,8 @@ KMPLAYER_NO_EXPORT Log & Log::operator << (const SRect &r) {
 }
 
 KMPLAYER_NO_EXPORT Log & Log::operator << (const IRect &r) {
-    fprintf (stderr, "SRect(%d, %d, %d, %d)", r.x, r.y, r.w, r.h);
+    fprintf (stderr, "SRect(%d, %d, %d, %d)",
+            r.x (), r.y (), r.width (), r.height ());
     return *this;
 }
 
@@ -1027,20 +1096,6 @@ KMPLAYER_NO_EXPORT Log & Log::operator << (void * d) {
 
 //-----------------------------------------------------------------------------
 
-GRect GRect::unite (const GRect & r) const {
-    GRect rect;
-    gdk_rectangle_union (m_rect, (GdkRectangle *) r, (GdkRectangle *) rect);
-    return rect;
-}
-
-GRect GRect::intersect (const GRect & r) const {
-    GRect rect;
-    gdk_rectangle_intersect (m_rect, (GdkRectangle *) r, (GdkRectangle *) rect);
-    return rect;
-}
-
-//-----------------------------------------------------------------------------
-
 #include <glib/gprintf.h>
 
 static GdkColor * colorFromRGB (int rgb) {
@@ -1079,85 +1134,6 @@ KMPLAYER_NO_CDTOR_EXPORT GColor::GColor (int rgb)
     //debugLog () << "GColor::GColor (int " << rgb << ") -> " << int (m_color ? m_color->pixel : -1) << " str:" << buf << endl;
 }
 
-//-----------------------------------------------------------------------------
-#if 0
-KMPLAYER_NO_CDTOR_EXPORT GPixmap::GPixmap (int w, int h) {
-    GdkVisual * visual = gdk_visual_get_system ();//gdk_rgb_get_visual
-    m_pixmap = gdk_pixmap_new (0L, w, h, visual->depth);
-}
-
-KMPLAYER_NO_CDTOR_EXPORT
-GPixmap::GPixmap (const ByteArray & data) : m_pixmap (0L) {
-    GdkPixbufLoader * pix_loader = gdk_pixbuf_loader_new ();
-    GError *gerror = 0L;
-    if (gdk_pixbuf_loader_write (pix_loader, (const guchar *) data.data (), data.size (), &gerror) && gdk_pixbuf_loader_close (pix_loader, 0L)) {
-        *this = gdk_pixbuf_loader_get_pixbuf (pix_loader);
-    } else
-        g_free (gerror);
-    g_object_unref (pix_loader);
-}
-
-KMPLAYER_NO_CDTOR_EXPORT GPixmap::GPixmap (GdkPixbuf * pb) : m_pixmap (0L) {
-    if (pb)
-        *this = pb;
-}
-
-KMPLAYER_NO_CDTOR_EXPORT
-GPixmap::GPixmap (const GPixmap & other) : m_pixmap (other.m_pixmap) {
-    if (m_pixmap)
-        g_object_ref (m_pixmap);
-}
-
-KMPLAYER_NO_CDTOR_EXPORT GPixmap::GPixmap (const Image & image) : m_pixmap(0L) {
-    const GPixbuf & gpb = (const GPixbuf) image;
-    GdkPixbuf * pb = gpb.pixbuf ();
-    if (pb)
-        *this = pb;
-}
-
-KMPLAYER_NO_CDTOR_EXPORT GPixmap::~GPixmap () {
-    if (m_pixmap)
-        g_object_unref (m_pixmap);
-}
-
-int GPixmap::width () const {
-    int w = 0, h;
-    if (m_pixmap)
-        gdk_drawable_get_size (GDK_DRAWABLE (m_pixmap), &w, &h);
-    return w;
-}
-
-int GPixmap::height () const {
-    int w, h = 0;
-    if (m_pixmap)
-        gdk_drawable_get_size (GDK_DRAWABLE (m_pixmap), &w, &h);
-    return h;
-}
-
-void GPixmap::fill (const Color & c) {
-    if (m_pixmap) {
-        int w, h;
-        gdk_drawable_get_size (GDK_DRAWABLE (m_pixmap), &w, &h);
-        GdkGC * gc = gdk_gc_new (GDK_DRAWABLE (m_pixmap));
-        gdk_draw_rectangle (GDK_DRAWABLE (m_pixmap), gc, true, 0, 0, w, h);
-        gdk_gc_unref (gc);
-    }
-}
-
-GPixmap &  GPixmap::operator = (GdkPixbuf * pixbuf) {
-    if (m_pixmap)
-        g_object_unref (m_pixmap);
-    int w = gdk_pixbuf_get_width (pixbuf);
-    int h = gdk_pixbuf_get_height (pixbuf);
-    GdkVisual * visual = gdk_visual_get_system ();
-    m_pixmap = gdk_pixmap_new (0L, w, h, visual->depth);
-    GdkColormap * cmap = gdk_colormap_get_system ();
-    gdk_drawable_set_colormap (GDK_DRAWABLE (m_pixmap), cmap);
-    GdkGC * gc = gdk_gc_new (GDK_DRAWABLE (m_pixmap));
-    gdk_draw_pixbuf (GDK_DRAWABLE (m_pixmap), gc, pixbuf, 0, 0, 0, 0, w, h, GDK_RGB_DITHER_NORMAL, 0, 0);
-    gdk_gc_unref (gc);
-}
-#endif
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_CDTOR_EXPORT GPixbuf::GPixbuf (int w, int h) {
@@ -1202,18 +1178,7 @@ KMPLAYER_NO_EXPORT GPixbuf & GPixbuf::operator = (const GPixbuf & other) {
     }
     return *this;
 }
-#if 0
-KMPLAYER_NO_EXPORT GPixbuf & GPixbuf::operator = (const Pixmap & pixmap) {
-    const GPixmap & gpm = (const GPixmap) pixmap;
-    GdkPixmap * pm = gpm.pixmap ();
-    reset ();
-    if (pm) {
-        GdkColormap * cmap = gdk_colormap_get_system ();
-        m_pixbuf = gdk_pixbuf_get_from_drawable (0L, GDK_DRAWABLE (pm), cmap, 0, 0, 0, 0, pixmap.width (), pixmap.height ());
-    }
-    return *this;
-}
-#endif
+
 KMPLAYER_NO_EXPORT void GPixbuf::reset () {
     if (m_pixbuf) {
         g_object_unref (m_pixbuf);
@@ -1232,196 +1197,6 @@ KMPLAYER_NO_EXPORT GPixbuf GPixbuf::scale (int w, int h) {
 }
 
 
-//-----------------------------------------------------------------------------
-
-/*
-namespace KMPlayer {
-    
-class GPainterPrivate {
-public:
-    GPainterPrivate ()
-        : m_drawable (0L), m_gc (0L),
-    m_pango_enabled (false), pango_bg ("white"), pango_fg ("black")  {}
-    GdkDrawable * m_drawable;
-    GdkGC * m_gc;
-    PangoRenderer *renderer;
-    PangoContext *context;
-    PangoLayout * layout;
-    Color pango_bg;
-    Color pango_fg;
-    bool m_pango_enabled;
-    void enablePango ();
-    void disablePango ();
-};
-
-}
-
-KMPLAYER_NO_EXPORT
-void GPainterPrivate::enablePango () {
-    if (!m_pango_enabled) {
-        m_pango_enabled = true;
-        GdkScreen *screen = gdk_drawable_get_screen (m_drawable);
-        renderer = gdk_pango_renderer_get_default (screen);
-        context = gdk_pango_context_get_for_screen (screen);
-        layout = pango_layout_new (context);
-        //pango_context_set_base_dir (context, gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR ?  PANGO_DIRECTION_LTR : PANGO_DIRECTION_RTL);
-        pango_context_set_base_dir (context, PANGO_DIRECTION_LTR);
-        //pango_context_set_font_description (context, widget->style->font_desc);
-        pango_context_set_language (context, gtk_get_default_language ());
-    }
-}
-
-KMPLAYER_NO_EXPORT
-void GPainterPrivate::disablePango () {
-    if (m_pango_enabled) {
-        m_pango_enabled = false;
-        g_object_unref (layout);
-        g_object_unref (context);
-    }
-}
-
-//-----------------------------------------------------------------------------
-
-KMPLAYER_NO_CDTOR_EXPORT 
-GPainter::GPainter ()
-    : d (new GPainterPrivate) {}
-
-KMPLAYER_NO_CDTOR_EXPORT GPainter::~GPainter () {
-    if (d->m_drawable)
-        end ();
-    delete d;
-}
-
-//KMPLAYER_NO_EXPORT GPainter::operator GdkGC * () const {
-//    return d->m_gc;
-//}
-
-GPainter::operator GdkDrawable * () const {
-    return d->m_drawable;
-}
-
-bool GPainter::begin (GdkDrawable * drawable, const Rect & rect) {
-    if (d->m_drawable)
-        return false;
-    d->m_drawable = drawable;
-    g_object_ref (G_OBJECT (d->m_drawable));
-    if (rect.width () <= 0) {
-        int w, h;
-        gdk_drawable_get_size (d->m_drawable, &w, &h);
-        m_drawrect = Rect (0, 0, w, h);
-    } else
-        m_drawrect = rect;
-    d->m_gc = gdk_gc_new (d->m_drawable);
-    d->m_pango_enabled = false;
-    m_cliprect = m_drawrect;
-    if (GDK_IS_WINDOW (d->m_drawable))
-        gdk_window_begin_paint_rect (d->m_drawable, (GdkRectangle *) (const GRect &) rect); 
-    return true;
-}
-
-bool GPainter::begin (const Pixmap * pm) {
-    const GPixmap & gpm = (const GPixmap) *pm;
-    return begin ((GdkDrawable *) gpm, Rect ());
-}
-
-bool GPainter::end () {
-    if (GDK_IS_WINDOW (d->m_drawable))
-        gdk_window_end_paint (d->m_drawable);
-    //debugLog () << "copyRect " << m_drawrect.x() << "," << m_drawrect.y() << " " << m_drawrect.width () << "x" << m_drawrect.height () << endl;
-    d->disablePango ();
-    g_object_unref (G_OBJECT (d->m_drawable));
-    d->m_drawable = 0L;
-    gdk_gc_unref (d->m_gc);
-    d->m_gc = 0L;
-    return true;
-}
-
-void GPainter::setClipRect (const Rect & rect) {
-    m_cliprect = rect;
-    gdk_gc_set_clip_rectangle (d->m_gc, (GdkRectangle *) (const GRect &) rect);
-}
-
-void GPainter::setClipping (bool enable) {
-    //setClipRect (enable ? m_cliprect : m_drawrect);
-}
-
-void GPainter::fillRect (int x, int y, int w, int h, const Color & c) {
-    const GColor color = (const GColor) c;
-  //debugLog () << " fillRect " << x << "," << y << " " << w << "x" << h<< endl;
-    gdk_gc_set_foreground (d->m_gc, (GdkColor *) color);
-    gdk_draw_rectangle (d->m_drawable, d->m_gc, true, x, y, w, h);
-}
-
-void GPainter::drawPixbuf (GdkPixbuf *p, int x, int y, int sx, int sy, int sw, int sh) {
-    gdk_draw_pixbuf (d->m_drawable, d->m_gc, p, sx, sy, x, y, sw, sh, GDK_RGB_DITHER_NORMAL, 0, 0);
-}
-
-void GPainter::drawPixmap (int dx, int dy, const Pixmap & pm, int sx, int sy, int sw, int sh) {
-    const GPixmap & gpm = (const GPixmap) pm;
-    GdkDrawable * p = (GdkDrawable *) gpm;
-    if (p && d->m_drawable) {
-        if (sw < 0 || sh < 0) {
-            int w, h;
-            gdk_drawable_get_size (p, &w, &h);
-            if (sw < 0)
-                sw = w;
-            if (sh < 0)
-                sh = h;
-        }
-        gdk_draw_drawable (d->m_drawable, d->m_gc, p, sx, sy, dx, dy, sw, sh);
-    }
-}
-
-void GPainter::drawImage (int dx, int dy, const Image & im, int sx, int sy, int sw, int sh) {
-    const GPixbuf & gpb = (const GPixbuf) im;
-    GdkPixbuf * pb = gpb.pixbuf ();
-    if (pb)
-        gdk_draw_pixbuf (d->m_drawable, d->m_gc, pb, sx, sy, dx, dy, sw, sh, GDK_RGB_DITHER_NORMAL, 0, 0);
-}
-
-void GPainter::drawText (const String & txt, int x, int y, int w, int h) {
-    // debugLog () << " drawText " << txt << " " << x << "," << y << " clip:" << m_cliprect.x () << "," <<  m_cliprect.y () << endl;
-    d->enablePango ();
-    pango_layout_set_width(d->layout, PANGO_SCALE *(w>0 ? w : m_cliprect.width()));
-    pango_layout_set_wrap (d->layout, PANGO_WRAP_WORD);
-    pango_layout_set_text (d->layout, (const char *) txt, -1);
-    //PangoMatrix matrix = PANGO_MATRIX_INIT;
-    //pango_matrix_translate (&matrix, pw * (x - m_drawrect.x ()), ph * (y - m_drawrect.y ()));
-    //pango_context_set_matrix (d->context, &matrix);
-    //pango_layout_context_changed (layout);
-    gdk_pango_renderer_set_drawable (GDK_PANGO_RENDERER (d->renderer), d->m_drawable);
-    gdk_pango_renderer_set_gc (GDK_PANGO_RENDERER (d->renderer), d->m_gc);
-    gdk_pango_renderer_set_override_color (GDK_PANGO_RENDERER (d->renderer),
-            PANGO_RENDER_PART_FOREGROUND, (GdkColor*) ((const GColor&) d->pango_fg));
-    gdk_pango_renderer_set_override_color (GDK_PANGO_RENDERER (d->renderer),
-            PANGO_RENDER_PART_BACKGROUND, (GdkColor*) ((const GColor&) d->pango_bg));
-    pango_renderer_set_matrix (d->renderer, NULL);
-    pango_renderer_activate (d->renderer);
-    pango_renderer_draw_layout (d->renderer, d->layout, PANGO_SCALE * x, PANGO_SCALE * y);
-    pango_renderer_deactivate (d->renderer);
-    gdk_pango_renderer_set_override_color (GDK_PANGO_RENDERER (d->renderer),
-            PANGO_RENDER_PART_FOREGROUND, NULL);
-    gdk_pango_renderer_set_override_color (GDK_PANGO_RENDERER (d->renderer),
-            PANGO_RENDER_PART_BACKGROUND, NULL);
-    gdk_pango_renderer_set_drawable (GDK_PANGO_RENDERER (d->renderer), NULL);
-    gdk_pango_renderer_set_gc (GDK_PANGO_RENDERER (d->renderer), NULL);
-}
-
-void GPainter::setPen (const Color & c) {
-    d->pango_fg = c;
-}
-
-void GPainter::setBackgroundColor (const Color & c) {
-    d->pango_bg = c;
-}
-
-void GPainter::setFont (const String & str) {
-    d->enablePango ();
-    PangoFontDescription *desc = pango_font_description_from_string ((const char *) str);
-    pango_layout_set_font_description (d->layout, desc);
-    pango_font_description_free (desc);
-}
-*/
 /*
 void        gdk_pixbuf_xlib_init            (Display *display,
                                              int screen_num);
